@@ -22,7 +22,7 @@
 library(R2MLwiN)
 ## Input the MLwiN tutorial data set
 # MLwiN folder
-if(!exists("mlwin")) mlwin ="C:/Program Files (x86)/MLwiN v2.26/"
+if(!exists("mlwin")) mlwin ="C:/Program Files (x86)/MLwiN v2.27/"
 while (!file.access(mlwin,mode=0)==0||!file.access(mlwin,mode=1)==0||!file.access(mlwin,mode=4)==0){
     cat("Please specify the MLwiN folder including the MLwiN executable:\n")
     mlwin=scan(what=character(0),sep ="\n")
@@ -41,7 +41,7 @@ library(foreign); indata =read.dta(inputfile)
 formula="ATTAIN~(0|CONS)+(3|CONS)+(1|CONS)"
 levID=c('SID','PID','PUPIL')
 estoptions= list(EstM=1)
-mymodel=runMLwiN(formula, levID, D='Normal', indata, estoptions,MLwiNPath=mlwin)
+(mymodel=runMLwiN(formula, levID, D='Normal', indata, estoptions,MLwiNPath=mlwin))
 
 # 15.4 A Cross-classified model . . . . . . . . . . . . . . . . . . . . .220
 
@@ -49,12 +49,12 @@ formula="ATTAIN~(0|CONS)+(3|CONS)+(2|CONS)+(1|CONS)"
 levID=c('SID','PID','PUPIL')
 xclass=list("classes"=c(2,3),"N1"=c(1,1))
 estoptions= list(xclass=xclass,EstM=1,notation='class',resi.store=T,resi.store.levs=c(2,3))
-mymodel=runMLwiN(formula, levID, D='Normal', indata, estoptions,MLwiNPath=mlwin)
+(mymodel=runMLwiN(formula, levID, D='Normal', indata, estoptions,MLwiNPath=mlwin))
 
 # 15.5 Residuals . . . . . . . . . . . . . . . . . . . . . . . . . . . . 223
 
 lencateg = length(unique(indata[["SID"]]))
-resi.chain0=na.omit(mymodel["resi.chains"][["resi_lev3"]])
+resi.chain0=na.omit(mymodel["resi.chains"][,"resi_lev3"])
 resi.chain0=matrix(resi.chain0, nrow =lencateg)
 residual0 = apply(resi.chain0,1,mean)
 rankno=order(residual0)
@@ -63,7 +63,7 @@ abline(h=0,lty="dotted")
 
 ## Common caterpillar
 #lencateg = length(unique(indata[["SID"]]))
-#resi.chain0=na.omit(mymodel["resi.chains"][["resi_lev3"]])
+#resi.chain0=na.omit(mymodel["resi.chains"][,"resi_lev3"])
 #resi.chain0=matrix(resi.chain0, nrow =lencateg)
 #u0rank = apply(resi.chain0,2,rank)
 #u0rankmn = apply(u0rank, 1,mean)
@@ -74,7 +74,7 @@ abline(h=0,lty="dotted")
 #caterpillar(y=u0rankmn[rankno],x=1:lencateg,qtlow=u0ranklo[rankno],qtup=u0rankhi[rankno]],ylim=c(0,20))
 
 lencateg = length(unique(indata[["PID"]]))
-resi.chain1=na.omit(mymodel["resi.chains"][["resi_lev2"]])
+resi.chain1=na.omit(mymodel["resi.chains"][,"resi_lev2"])
 resi.chain1=matrix(resi.chain1, nrow =lencateg)
 residual1 = apply(resi.chain1,1,mean)
 rankno=order(residual1)
@@ -83,7 +83,7 @@ abline(h=0,lty="dotted")
 
 ## Common caterpillar
 #lencateg = length(unique(indata[["PID"]]))
-#resi.chain1=na.omit(mymodel["resi.chains"][["resi_lev2"]])
+#resi.chain1=na.omit(mymodel["resi.chains"][,"resi_lev2"])
 #resi.chain1=matrix(resi.chain1, nrow =lencateg)
 #u0rank = apply(resi.chain1,2,rank)
 #u0rankmn = apply(u0rank, 1,mean)
@@ -99,16 +99,16 @@ formula="ATTAIN~(0|CONS+VRQ)+(3|CONS)+(2|CONS)+(1|CONS)"
 levID=c('SID','PID','PUPIL')
 xclass=list("classes"=c(2,3),"N1"=c(1,1))
 estoptions= list(xclass=xclass,EstM=1,notation='class',resi.store=T,resi.store.levs=c(2,3))
-mymodel=runMLwiN(formula, levID, D='Normal', indata, estoptions,MLwiNPath=mlwin)
+(mymodel=runMLwiN(formula, levID, D='Normal', indata, estoptions,MLwiNPath=mlwin))
 
 formula="ATTAIN~(0|CONS+VRQ+SC+FED+MED+CHOICE)+(3|CONS)+(2|CONS)+(1|CONS)"
 levID=c('SID','PID','PUPIL')
 xclass=list("classes"=c(2,3),"N1"=c(1,1))
 estoptions= list(xclass=xclass,EstM=1,notation='class',resi.store=T,resi.store.levs=c(2,3))
-mymodel=runMLwiN(formula, levID, D='Normal', indata, estoptions,MLwiNPath=mlwin)
+(mymodel=runMLwiN(formula, levID, D='Normal', indata, estoptions,MLwiNPath=mlwin))
 
 lencateg = length(unique(indata[["SID"]]))
-resi.chain0=na.omit(mymodel["resi.chains"][["resi_lev3"]])
+resi.chain0=na.omit(mymodel["resi.chains"][,"resi_lev3"])
 resi.chain0=matrix(resi.chain0, nrow =lencateg)
 residual0 = apply(resi.chain0,1,mean)
 rankno=order(residual0)
@@ -120,7 +120,7 @@ formula="ATTAIN~(0|CONS+VRQ+SC+FED+MED+CHOICE+school19)+(2|CONS)+(1|CONS)"
 levID=c('SID','PID','PUPIL')
 xclass=list("classes"=c(2,3),"N1"=c(1,1))
 estoptions= list(xclass=xclass,EstM=1,notation='class')
-mymodel=runMLwiN(formula, levID, D='Normal', indata, estoptions,MLwiNPath=mlwin)
+(mymodel=runMLwiN(formula, levID, D='Normal', indata, estoptions,MLwiNPath=mlwin))
 
 # 15.7 Current restrictions for cross-classified models . . . . . . . . .229
 
